summaryrefslogtreecommitdiff
path: root/package/source
diff options
context:
space:
mode:
authorAndrea Gelmini <andrea.gelmini@gelma.net>2015-01-02 15:51:30 +0100
committerEike Rathke <erack@redhat.com>2015-01-02 20:23:51 +0000
commit3a2b1af87d629a780f0e98559fb8b409378a80c7 (patch)
treeecf27171a38a2d6d4b05b4acd42e8e98b7f7d70a /package/source
parentd7794d2584cd5d476b011b5344c77ad59c179c58 (diff)
Fix simple typos.
Change-Id: I1fdbe47ed7a6e05d2cf20f4c296bffad4bbc6599 Reviewed-on: https://gerrit.libreoffice.org/13719 Reviewed-by: Eike Rathke <erack@redhat.com> Tested-by: Eike Rathke <erack@redhat.com>
Diffstat (limited to 'package/source')
-rw-r--r--package/source/xstor/xstorage.cxx22
1 files changed, 11 insertions, 11 deletions
diff --git a/package/source/xstor/xstorage.cxx b/package/source/xstor/xstorage.cxx
index 9c345d699fe1..254c2b2b0489 100644
--- a/package/source/xstor/xstorage.cxx
+++ b/package/source/xstor/xstorage.cxx
@@ -766,7 +766,7 @@ void OStorage_Impl::CopyToStorage( const uno::Reference< embed::XStorage >& xDes
xRels->insertRelationships( GetAllRelationshipsIfAny(), sal_False );
}
- // if possible the destination storage should be commited after successful copying
+ // if possible the destination storage should be committed after successful copying
uno::Reference< embed::XTransactedObject > xObjToCommit( xDest, uno::UNO_QUERY );
if ( xObjToCommit.is() )
xObjToCommit->commit();
@@ -996,7 +996,7 @@ void OStorage_Impl::CopyLastCommitTo( const uno::Reference< embed::XStorage >& x
{
::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
- SAL_WARN_IF( !m_xPackageFolder.is(), "package.xstor", "A commited storage is incomplete!" );
+ SAL_WARN_IF( !m_xPackageFolder.is(), "package.xstor", "A committed storage is incomplete!" );
if ( !m_xPackageFolder.is() )
throw uno::RuntimeException( THROW_WHERE );
@@ -1035,10 +1035,10 @@ void OStorage_Impl::Commit()
// in case of a new empty storage it is possible that the contents are still not read
// ( the storage of course has no contents, but the initialization is postponed till the first use,
// thus if a new storage was created and commited immediately it must be initialized here )
ReadContents();
- // if storage is commited it should have a valid Package representation
+ // if storage is committed it should have a valid Package representation
SAL_WARN_IF( !m_xPackageFolder.is(), "package.xstor", "The package representation should exist!" );
if ( !m_xPackageFolder.is() )
throw embed::InvalidStorageException( THROW_WHERE );
@@ -1049,7 +1049,7 @@ void OStorage_Impl::Commit()
uno::Reference< container::XNameContainer > xNewPackageFolder;
// here the storage will switch to the temporary package folder
- // if the storage was already commited and the parent was not commited after that
+ // if the storage was already committed and the parent was not committed after that
// the switch should not be done since the package folder in use is a temporary one;
// it can be detected by m_bCommited flag ( root storage doesn't need temporary representation )
if ( !m_bCommited && !m_bIsRoot )
@@ -1117,7 +1117,7 @@ void OStorage_Impl::Commit()
if ( !(*pElementIter)->m_bIsInserted )
{
// for now stream is opened in direct mode that means that in case
// storage is commited all the streams from it are commited in current state.
// following two steps are separated to allow easily implement transacted mode
// for streams if we need it in future.
// Only hierarchical access uses transacted streams currently
@@ -1126,7 +1126,7 @@ void OStorage_Impl::Commit()
(*pElementIter)->m_pStream->Commit();
// if the storage was not open, there is no need to commit it ???
// the storage should be checked that it is commited
if ( (*pElementIter)->m_bIsStorage && (*pElementIter)->m_pStorage && (*pElementIter)->m_pStorage->m_bCommited )
{
// it's temporary PackageFolder should be inserted instead of current one
@@ -1447,7 +1447,7 @@ SotElement_Impl* OStorage_Impl::InsertRawStream( const OUString& aName, const un
// the mode is not needed for storage stream internal implementation
SotElement_Impl* pNewElement = InsertElement( aName, false );
pNewElement->m_pStream = new OWriteStream_Impl( this, xPackageSubStream, m_xPackage, m_xContext, true, m_nStorageType, false );
// the stream is inserted and must be treated as a commited one
pNewElement->m_pStream->SetToBeCommited();
m_aChildrenList.push_back( pNewElement );
@@ -2016,7 +2016,7 @@ void SAL_CALL OStorage::InternalDispose( bool bNotifyImpl )
delete m_pImpl;
else
{
// the noncommited changes for the storage must be removed
m_pImpl->Revert();
}
}
@@ -2084,7 +2084,7 @@ void OStorage::BroadcastModifiedIfNecessary()
void OStorage::BroadcastTransaction( sal_Int8 nMessage )
/*
1 - preCommit
- 2 - commited
+ 2 - committed
3 - preRevert
4 - reverted
*/
@@ -3972,7 +3972,7 @@ void SAL_CALL OStorage::commit()
m_pImpl->Commit(); // the root storage initiates the storing to source
- // when the storage is commited the parent is modified
+ // when the storage is committed the parent is modified
if ( m_pImpl->m_pParent && m_pImpl->m_pParent->m_pAntiImpl )
xParentModif = (util::XModifiable*)m_pImpl->m_pParent->m_pAntiImpl;
}
@@ -1035,10 +1035,10 @@ void OStorage_Impl::Commit()
// in case of a new empty storage it is possible that the contents are still not read
// ( the storage of course has no contents, but the initialization is postponed till the first use,
- // thus if a new storage was created and commited immediately it must be initialized here )
+ // thus if a new storage was created and committed immediately it must be initialized here )
ReadContents();
@@ -1117,7 +1117,7 @@ void OStorage_Impl::Commit()
{
// for now stream is opened in direct mode that means that in case
- // storage is commited all the streams from it are commited in current state.
+ // storage is committed all the streams from it are committed in current state.
// following two steps are separated to allow easily implement transacted mode
// for streams if we need it in future.
@@ -1126,7 +1126,7 @@ void OStorage_Impl::Commit()
(*pElementIter)->m_pStream->Commit();
// if the storage was not open, there is no need to commit it ???
- // the storage should be checked that it is commited
+ // the storage should be checked that it is committed
if ( (*pElementIter)->m_bIsStorage && (*pElementIter)->m_pStorage && (*pElementIter)->m_pStorage->m_bCommited )
{
@@ -1447,7 +1447,7 @@ SotElement_Impl* OStorage_Impl::InsertRawStream( const OUString& aName, const un
SotElement_Impl* pNewElement = InsertElement( aName, false );
pNewElement->m_pStream = new OWriteStream_Impl( this, xPackageSubStream, m_xPackage, m_xContext, true, m_nStorageType, false );
- // the stream is inserted and must be treated as a commited one
+ // the stream is inserted and must be treated as a committed one
pNewElement->m_pStream->SetToBeCommited();
m_aChildrenList.push_back( pNewElement );
@@ -2016,7 +2016,7 @@ void SAL_CALL OStorage::InternalDispose( bool bNotifyImpl )
else
{
- // the noncommited changes for the storage must be removed
+ // the non-committed changes for the storage must be removed
m_pImpl->Revert();
}